﻿Imports Model.Esperanto

Public Class LibrosManager

#Region "Singleton"

    ''' <summary>
    ''' Variable que contiene la instancia de esta clase
    ''' </summary>
    ''' <remarks>JAC: 06.05.2013</remarks>
    Private Shared _instance As New LibrosManager()

    ''' <summary>
    ''' Propiedad que contiene la instancia de esta clase
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>06.05.2013</remarks>
    Public Shared ReadOnly Property Instance() As LibrosManager
        Get
            If _instance Is Nothing Then
                _instance = New LibrosManager()
            End If
            Return _instance
        End Get
    End Property

    ''' <summary>
    ''' Constructor privado
    ''' </summary>
    ''' <remarks>JAC: 06.05.2013</remarks>
    Private Sub New()

    End Sub

#End Region

#Region "public"

    ''' <summary>
    ''' Retorna la lista de autores
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>JAC: 06.05.2013</remarks>
    Public Function Get_Autor() As List(Of Autor)

        Dim autores As List(Of Autor) = Nothing
        Dim DC As New EsperantoEntities

        Try
            autores = DC.spd_GetAutores().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return autores

    End Function

    ''' <summary>
    ''' Retorna un listado de editoriales
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>JAC: 06.05.2013</remarks>
    Public Function Get_Editorial() As List(Of Editorial)

        Dim editoriales As List(Of Editorial) = Nothing
        Dim DC As New EsperantoEntities

        Try
            editoriales = DC.spd_GetEditoriales().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return editoriales

    End Function

    ''' <summary>
    ''' Retorna un listado de géneros
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>JAC: 06.05.2013</remarks>
    Public Function Get_Genero() As List(Of Genero)

        Dim generos As List(Of Genero) = Nothing
        Dim DC As New EsperantoEntities

        Try
            generos = DC.spd_GetGeneros().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return generos

    End Function

    ''' <summary>
    ''' Busca libros en función de los parámetros de búsqueda
    ''' </summary>
    ''' <param name="Titulo"></param>
    ''' <param name="Editorial"></param>
    ''' <param name="Autor"></param>
    ''' <param name="Genero"></param>
    ''' <param name="Disponibilidad"></param>
    ''' <param name="ISBN"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 07.04.2013</remarks>
    Public Function Buscar(ByVal Titulo As String, ByVal Editorial As Integer, ByVal Autor As Integer, ByVal Genero As Integer, ByVal Disponibilidad As Integer, ByVal ISBN As String, ByVal IdiomaId As Integer, ByVal TipoId As Integer, ByVal Prestado As Integer) As List(Of Libros)

        Dim DC As New EsperantoEntities
        Dim libros As List(Of Libros)

        Try

            libros = DC.spd_SearchLibros(Titulo, Editorial, Autor, Genero, Disponibilidad, ISBN, IdiomaId, TipoId, Prestado).ToList

            For Each libro As Libros In libros
                libro.GeneroReference.Load()
                libro.AutorReference.Load()
                libro.EditorialReference.Load()
                libro.IdiomaLibroReference.Load()
                libro.TipoDocumentoReference.Load()
            Next

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return libros

    End Function

    ''' <summary>
    ''' Retorna un libro en base a su identificador
    ''' </summary>
    ''' <param name="LibroId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 08.05.2013</remarks>
    Public Function GetLibro(ByVal LibroId As Integer) As Libros

        Dim DC As New EsperantoEntities
        Dim libro As Libros


        Try

            libro = DC.spd_GetLibro(LibroId).SingleOrDefault

            libro.GeneroReference.Load()
            libro.AutorReference.Load()
            libro.EditorialReference.Load()
            libro.IdiomaLibroReference.Load()
            libro.TipoDocumentoReference.Load()

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return libro

    End Function

    ''' <summary>
    ''' Agrega un libro a la base de datos y retorna su identificador
    ''' </summary>
    ''' <param name="libro"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 11.05.2013</remarks>
    Public Function AddLibro(ByVal libro As Libros) As Integer

        Dim DC As New EsperantoEntities
        Dim libroId As Integer

        Try

            With libro

                libroId = DC.spd_AddLibro(.Titulo, .ISBN, .TipoId, .IdiomaId, .EditorialId, .AutorId, .GeneroId, .Stock, .Sinopsis).SingleOrDefault

            End With

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return libroId

    End Function

    ''' <summary>
    ''' Actualiza un libro en la base de datos y retorna su identificador
    ''' </summary>
    ''' <param name="libro"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 11.05.2013</remarks>
    Public Function EditLibro(ByVal libro As Libros) As Integer

        Dim DC As New EsperantoEntities
        Dim libroId As Integer

        Try

            With libro

                DC.spd_UpdateLibro(.LibroId, .Titulo, .ISBN, .TipoId, .IdiomaId, .EditorialId, .AutorId, .GeneroId, .Stock, .Sinopsis)

            End With

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return libroId

    End Function

    Public Function GetTipoLibro() As List(Of TipoDocumento)

        Dim tipos As List(Of TipoDocumento) = Nothing
        Dim DC As New EsperantoEntities

        Try
            tipos = DC.spd_GetTipoLibro().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return tipos

    End Function

    Public Function GetIdiomaLibro() As List(Of IdiomaLibro)

        Dim idiomas As List(Of IdiomaLibro) = Nothing
        Dim DC As New EsperantoEntities

        Try
            idiomas = DC.spd_GetIdiomaLibro().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return idiomas

    End Function

#End Region

End Class
