﻿Option Explicit On
Option Strict On

Imports Model.Esperanto

Public Class PrestamosManager

#Region "Singleton"

    ''' <summary>
    ''' Variable que contiene la instancia de esta clase
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Private Shared _instance As New PrestamosManager()

    ''' <summary>
    ''' Propiedad que contiene la instancia de esta clase
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Shared ReadOnly Property Instance() As PrestamosManager
        Get
            If _instance Is Nothing Then
                _instance = New PrestamosManager()
            End If
            Return _instance
        End Get
    End Property

    ''' <summary>
    ''' Constructor privado
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Private Sub New()

    End Sub

#End Region

#Region "Public"

    ''' <summary>
    ''' Retorna una lista estados de los préstamos
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Function GetEstadoPrestamo() As List(Of EstadoPrestamo)

        Dim DC As New EsperantoEntities
        Dim EstadosPrestamos As List(Of EstadoPrestamo)

        Try

            EstadosPrestamos = DC.spd_GetEstadoPrestamo().ToList

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return EstadosPrestamos

    End Function

    ''' <summary>
    ''' Agrega un préstamo para un usuario
    ''' </summary>
    ''' <param name="ReservaId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 22.05.2013</remarks>
    Function AddPrestamo(ByVal ReservaId As Integer) As Prestamos

        Dim DC As New EsperantoEntities
        Dim prestec As Prestamos

        Try

            prestec = DC.spd_AddPrestamo(ReservaId).SingleOrDefault

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return prestec

    End Function

    ''' <summary>
    ''' Retorna un lista con los préstamos que tiene el usuario
    ''' </summary>
    ''' <param name="UserId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 24.05.2013</remarks>
    Function GetPrestamosByUserId(ByVal UserId As Integer) As List(Of Prestamos)

        Dim DC As New EsperantoEntities
        Dim prestamos As List(Of Prestamos)

        Try

            prestamos = DC.spd_GetPrestamosByUserId(UserId).ToList

            For Each prestec As Prestamos In prestamos

                prestec.LibrosReference.Load()
                prestec.Libros.AutorReference.Load()

            Next

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return prestamos

    End Function

    ''' <summary>
    ''' Realiza una búsqueda de los prestamos en función de los parámetros de entrada
    ''' </summary>
    ''' <param name="PrestamoId"></param>
    ''' <param name="UserId"></param>
    ''' <param name="NIF"></param>
    ''' <param name="Titulo"></param>
    ''' <param name="AutorId"></param>
    ''' <param name="ISBN"></param>
    ''' <param name="EstadoPrestamo"></param>
    ''' <param name="FechaPrestamoIni"></param>
    ''' <param name="FechaPrestamoFin"></param>
    ''' <param name="FechaRetornoIni"></param>
    ''' <param name="FechaRetornoFin"></param>
    ''' <param name="FueraPlazo"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 25.05.2013</remarks>
    Public Function Buscar(ByVal PrestamoId As Integer, ByVal UserId As Integer, ByVal NIF As String, ByVal Titulo As String, ByVal AutorId As Integer,
                               ByVal ISBN As String, ByVal EstadoPrestamo As EstadoPrestamoEnum,
                               ByVal FechaPrestamoIni As Nullable(Of Date), ByVal FechaPrestamoFin As Nullable(Of Date),
                               ByVal FechaRetornoIni As Nullable(Of Date), ByVal FechaRetornoFin As Nullable(Of Date),
                               ByVal FueraPlazo As Integer, ByVal FechaRetornaMax As Integer) As List(Of Prestamos)


        Dim DC As New EsperantoEntities
        Dim Prestamo As List(Of Prestamos)

        Try

            Prestamo = DC.spd_SearchPrestamos(UserId, NIF, PrestamoId, Titulo, AutorId, EstadoPrestamo, ISBN,
                                              FechaPrestamoIni, FechaPrestamoFin, FechaRetornoIni, FechaRetornoFin, FueraPlazo, FechaRetornaMax).ToList

            For Each item As Prestamos In Prestamo

                item.LibrosReference.Load()
                item.Libros.AutorReference.Load()

            Next

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return Prestamo

    End Function

    ''' <summary>
    ''' Retorna un préstamo en base a su identificador
    ''' </summary>
    ''' <param name="PrestamoId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 25.05.2013</remarks>
    Function RetornarPrestamo(ByVal PrestamoId As Integer) As Prestamos

        Dim DC As New EsperantoEntities
        Dim prestec As Prestamos

        Try

            prestec = DC.spd_RetornarPestamo(PrestamoId).SingleOrDefault

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return prestec

    End Function

    ''' <summary>
    ''' Retorna préstamo en base a su identificador
    ''' </summary>
    ''' <param name="PrestamoId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 25.05.2013</remarks>
    Function GetPrestamo(ByVal PrestamoId As Integer) As Prestamos

        Dim DC As New EsperantoEntities
        Dim prestec As Prestamos

        Try

            prestec = DC.spd_GetPrestamoByPrestamoId(PrestamoId).SingleOrDefault

            prestec.LibrosReference.Load()
            prestec.Libros.AutorReference.Load()
            prestec.Libros.EditorialReference.Load()
            prestec.Libros.GeneroReference.Load()
            prestec.EstadoPrestamoReference.Load()
            prestec.UsuariosReference.Load()


        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return prestec

    End Function

#End Region

End Class
