﻿Option Explicit On
Option Strict On

Imports Model.Esperanto

Public Class ReservasManager

#Region "Singleton"

    ''' <summary>
    ''' Variable que contiene la instancia de esta clase
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Private Shared _instance As New ReservasManager()

    ''' <summary>
    ''' Propiedad que contiene la instancia de esta clase
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Shared ReadOnly Property Instance() As ReservasManager
        Get
            If _instance Is Nothing Then
                _instance = New ReservasManager()
            End If
            Return _instance
        End Get
    End Property

    ''' <summary>
    ''' Constructor privado
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Private Sub New()

    End Sub

#End Region


#Region "Public"

    ''' <summary>
    ''' Agrega un nuevo usuario a la aplicación
    ''' </summary>
    ''' <param name="UserId"></param>
    ''' <param name="LibroId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 16.04.2013</remarks>
    Public Function AddReserva(ByVal UserId As Integer, ByVal LibroId As Integer) As Reservas

        Dim DC As New EsperantoEntities
        Dim Reservas As Reservas

        Try

            Reservas = DC.spd_AddReserva(UserId, LibroId).SingleOrDefault

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return Reservas

    End Function

    ''' <summary>
    ''' Retorna una lista de reservas que tiene un usuario
    ''' </summary>
    ''' <param name="UserId"></param>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Function GetReservasByUserId(ByVal UserId As Integer) As List(Of Reservas)

        Dim DC As New EsperantoEntities
        Dim reservas As List(Of Reservas)

        Try

            reservas = DC.spd_GetReservasByUserId(UserId).ToList

            For Each reserva As Reservas In reservas

                reserva.LibrosReference.Load()
                reserva.Libros.AutorReference.Load()

            Next

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return reservas

    End Function

    ''' <summary>
    ''' Retorna una lista estados de las reservas
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Function GetEstadosReserva() As List(Of EstadoReserva)

        Dim DC As New EsperantoEntities
        Dim EstadosReservas As List(Of EstadoReserva)

        Try

            EstadosReservas = DC.spd_GetEstadoReserva().ToList

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return EstadosReservas

    End Function

    ''' <summary>
    ''' Cancela la reserva de un usuario en base al identificador de la reserva
    ''' </summary>
    ''' <param name="ReservaId"></param>
    ''' <remarks>JAC: 19.05.2013</remarks>
    Public Sub Cancelar(ByVal ReservaId As Integer)

        Dim DC As New EsperantoEntities

        Try

            DC.spd_CancelarReserva(ReservaId)

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

    End Sub

    ''' <summary>
    ''' Busca reservas con los parámetros de búsqueda indicados
    ''' </summary>
    ''' <param name="UserId"></param>
    ''' <param name="Titulo"></param>
    ''' <param name="AutorId"></param>
    ''' <param name="ISBN"></param>
    ''' <param name="EstadoReserva"></param>
    ''' <param name="FechaReservaIni"></param>
    ''' <param name="FechaReservaFin"></param>
    ''' <param name="FechaCancelacionIni"></param>
    ''' <param name="FechaCancelacionFin"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 19.05.2013</remarks>
    Public Function Buscar(ByVal ReservaId As Integer, ByVal UserId As Integer, ByVal NIF As String, ByVal Titulo As String, ByVal AutorId As Integer,
                               ByVal ISBN As String, ByVal EstadoReserva As EstadoReservaEnum,
                               ByVal FechaReservaIni As Nullable(Of Date), ByVal FechaReservaFin As Nullable(Of Date),
                               ByVal FechaCancelacionIni As Nullable(Of Date), ByVal FechaCancelacionFin As Nullable(Of Date)) As List(Of Reservas)


        Dim DC As New EsperantoEntities
        Dim Reserva As List(Of Reservas)

        Try

            Reserva = DC.spd_SearchReservas(UserId, NIF, ReservaId, Titulo, AutorId, EstadoReserva, ISBN, FechaReservaIni, FechaReservaFin, FechaCancelacionIni, FechaCancelacionFin).ToList

            For Each item As Reservas In Reserva

                item.LibrosReference.Load()
                item.Libros.AutorReference.Load()

            Next

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return Reserva

    End Function

#End Region
    ''' <summary>
    ''' Consulta una reserva en la bbdd con su identificador
    ''' </summary>
    ''' <param name="ReservaId"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 21.05.2013</remarks>
    Function GetReserva(ByVal ReservaId As Integer) As Reservas

        Dim DC As New EsperantoEntities
        Dim reserva As Reservas

        Try

            reserva = DC.spd_GetReservaByReservaId(ReservaId).SingleOrDefault

            reserva.LibrosReference.Load()
            reserva.Libros.AutorReference.Load()
            reserva.Libros.EditorialReference.Load()
            reserva.Libros.GeneroReference.Load()
            reserva.EstadoReservaReference.Load()
            reserva.UsuariosReference.Load()


        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return reserva

    End Function

End Class
