﻿Option Explicit On
Option Strict On

Imports Model.Esperanto


Public NotInheritable Class TraduccionesManager

#Region "Singleton"
    Private Shared ReadOnly lazy As New Lazy(Of TraduccionesManager)(Function() New TraduccionesManager())

    Public Shared ReadOnly Property Instance() As TraduccionesManager
        Get
            Return lazy.Value
        End Get
    End Property

    Private Sub New()
    End Sub
#End Region

    ''' <summary>
    ''' Función que retorna todas las traducciones del idioma informado
    ''' </summary>
    ''' <param name="IdIdioma">Indica el código del idioma</param>
    ''' <returns>Si se produce un error al realizar la petición, retorna <code>Nothing</code>.
    ''' Si la solicitud va bien, retorna la lista de traducciones</returns>
    ''' <remarks></remarks>
    Public Function GetAllTraducciones(ByVal IdIdioma As Integer) As List(Of vwTraducciones)

        Dim sw As Stopwatch = Stopwatch.StartNew()
        Dim LlistaTraduccions As List(Of vwTraducciones) = Nothing

        Using ctx As New EsperantoEntities()
            Try
                LlistaTraduccions = ctx.spd_PI_Get_Traducciones(String.Empty, IdIdioma).ToList()
                sw.Stop()
            Catch ex As Exception

            End Try
        End Using

        Return LlistaTraduccions

    End Function

End Class