﻿Imports Model.Esperanto

Public Class UsuariosManager

#Region "Singleton"

    ''' <summary>
    ''' Variable que contiene la instancia de esta clase
    ''' </summary>
    ''' <remarks>JAC: 12.04.2013</remarks>
    Private Shared _instance As New UsuariosManager()

    ''' <summary>
    ''' Propiedad que contiene la instancia de esta clase
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 12.04.2013</remarks>
    Public Shared ReadOnly Property Instance() As UsuariosManager
        Get
            If _instance Is Nothing Then
                _instance = New UsuariosManager()
            End If
            Return _instance
        End Get
    End Property

    ''' <summary>
    ''' Constructor privado
    ''' </summary>
    ''' <remarks>JAC: 12.04.2013</remarks>
    Private Sub New()

    End Sub

#End Region

    ''' <summary>
    ''' Selecciona un usuario en función de su NIF y password
    ''' Si el usuario existe lo guarda en la session y retorna true
    ''' Si el usuario no existe retorna false
    ''' </summary>
    ''' <param name="NIF"></param>
    ''' <param name="Pass"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 14.04.2013</remarks>
    Public Function Login(ByVal NIF As String, ByVal Pass As String) As Usuarios

        Dim DC As New EsperantoEntities
        Dim usuario As Usuarios

        Try

            usuario = DC.spd_Login(NIF, Pass).SingleOrDefault

        Catch ex As Exception
            usuario = New Usuarios
        Finally
            DC.Dispose()
        End Try

        Return usuario

    End Function

    ''' <summary>
    ''' Agrega un nuevo usuario a la aplicación
    ''' </summary>
    ''' <param name="user"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 16.04.2013</remarks>
    Public Function AddUser(ByVal user As Usuarios) As Integer

        Dim DC As New EsperantoEntities
        Dim usuarioID As Integer

        Try

            With user

                usuarioID = DC.spd_AddUser(.NIF, .Nombre, .Apellido1, .Apellido2, .Telf, .Direccion, .Poblacion, .Email, .Password, .RolId,
                                         .FechaNacimiento, .FechaAlta, .FechaBaja, EstadoUsuario.Activo, .IdIdioma).SingleOrDefault


            End With

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return usuarioID

    End Function

    ''' <summary>
    ''' Obtiene un usuario de la base de datos
    ''' </summary>
    ''' <param name="Id"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 21.04.2013</remarks>
    Public Function GetUser(Id As Integer) As Usuarios

        Dim DC As New EsperantoEntities
        Dim usuario As Usuarios


        Try

            usuario = DC.spd_GetUser(Id).Singleordefault

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return usuario

    End Function

    ''' <summary>
    ''' Actualiza un usuario con los datos recogidos en la pantalla
    ''' </summary>
    ''' <param name="user"></param>
    ''' <remarks></remarks>
    Public Function UpdateUser(ByVal user As Usuarios) As Integer

        Dim DC As New EsperantoEntities
        Dim usuarioID As Integer

        Try

            With user

                If user.Estado = EstadoUsuario.Inactivo Then
                    user.FechaBaja = Now
                End If

                usuarioID = DC.spd_UpdateUser(.UserId, .NIF, .Nombre, .Apellido1, .Apellido2, .Telf, .Direccion, .Poblacion, .Email,
                                              .RolId, .FechaNacimiento, .FechaAlta, .FechaBaja, .Estado, .IdIdioma).SingleOrDefault

            End With

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return usuarioID

    End Function

    ''' <summary>
    ''' Busca usuarios en función de los parámetros de búsqueda
    ''' </summary>
    ''' <param name="Nombre"></param>
    ''' <param name="Apellido1"></param>
    ''' <param name="Apellido2"></param>
    ''' <param name="Telefono"></param>
    ''' <param name="Rol"></param>
    ''' <param name="NIF"></param>
    ''' <param name="Poblacion"></param>
    ''' <param name="Estado"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 20.04.2013</remarks>
    Function Buscar(ByVal Nombre As String, ByVal Apellido1 As String, ByVal Apellido2 As String,
                               ByVal Telefono As String, ByVal NIF As String,
                               ByVal Poblacion As String, ByVal Rol As RolEnum, ByVal Estado As Integer, ByVal Prestado As Integer) As List(Of Usuarios)


        Dim DC As New EsperantoEntities
        Dim usuarios As List(Of Usuarios)


        Try

            usuarios = DC.spd_SearchUser(Nombre, Apellido1, Apellido2, Telefono, NIF, Poblacion, Rol, Estado, Prestado).ToList

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return usuarios

    End Function

    ''' <summary>
    ''' Verifica si existe un usuario con los datos informados y lo retorna
    ''' </summary>
    ''' <param name="NIF"></param>
    ''' <param name="Email"></param>
    ''' <param name="FechaNacimiento"></param>
    ''' <returns></returns>
    ''' <remarks>JAC: 25.04.2013</remarks>
    Public Function Recover(ByVal NIF As String, ByVal Email As String, ByVal FechaNacimiento As Date) As Usuarios

        Dim DC As New EsperantoEntities
        Dim usuario As Usuarios


        Try

            usuario = DC.spd_Recover(NIF, Email, FechaNacimiento).SingleOrDefault

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return usuario

    End Function

    ''' <summary>
    ''' Actualiza la contraseña de un usuario
    ''' </summary>
    ''' <param name="UserId"></param>
    ''' <param name="Password"></param>
    ''' <remarks>JAC: 26.04.2013</remarks>
    Public Sub UpdatePass(ByVal UserId As Integer, ByVal Password As String)

        Dim DC As New EsperantoEntities

        Try

            DC.spd_UpdatePass(UserId, Password)

        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

    End Sub

#Region "Combos"

    ''' <summary>
    ''' Retorna un listado rol
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks>JAC: 14.04.2013</remarks>
    Public Function Get_Rol() As List(Of Rol)

        Dim UsersRols As List(Of Rol) = Nothing
        Dim DC As New EsperantoEntities

        Try
            UsersRols = DC.spd_GetRols().ToList
        Catch ex As Exception
            Throw ex
        Finally
            DC.Dispose()
        End Try

        Return UsersRols

    End Function

#End Region

End Class
