﻿Public Class CacheBaseHelper

    Private Shared Function Retrieve(ByVal key As String) As Object

        Dim CacheValue As Object = Nothing

        If Not String.IsNullOrWhiteSpace(key) Then
            CacheValue = HttpContext.Current.Cache(key)
        End If

        Return CacheValue

    End Function

    Public Shared Function Exists(ByVal key As String) As Boolean

        Return Retrieve(key) IsNot Nothing

    End Function

    Public Shared Sub Insert(ByVal key As String, ByVal obj As Object)

        Dim OneDay As New TimeSpan(1, 0, 0, 0)
        Insert(key, obj, OneDay)

    End Sub

    Public Shared Sub Insert(ByVal key As String, ByVal obj As Object, ByVal span As TimeSpan)

        If Exists(key) Then
            Clear(key)
        End If

        HttpContext.Current.Cache.Add(
        key,
        obj,
        Nothing,
        DateTime.Now.Add(span),
        Cache.NoSlidingExpiration,
        CacheItemPriority.Normal,
        Nothing)

    End Sub

    Public Shared Sub InsertWithFileDependency(ByVal key As String, ByVal obj As Object, ByVal FileName As String)

        If Exists(key) Then
            Clear(key)
        End If

        If IO.File.Exists(FileName) Then
            HttpContext.Current.Cache.Insert(key, obj, New CacheDependency(FileName))
        End If

    End Sub


    Public Shared Sub Clear(ByVal key As String)

        If Exists(key) Then
            HttpContext.Current.Cache.Remove(key)
        End If

    End Sub

    Public Shared Function Retrieve(Of T)(ByVal key As String) As T
        Dim CacheValue As Object = Retrieve(key)
        Return CType(CacheValue, T)
    End Function

    Public Shared Sub ClearAll()

        Dim keys As New List(Of String)()
        Dim enumerator As IDictionaryEnumerator = HttpContext.Current.Cache.GetEnumerator()

        While enumerator.MoveNext
            keys.Add(enumerator.Key.ToString())
        End While

        For Each key As String In keys
            Clear(key)
        Next

    End Sub

End Class