﻿Imports System.Web
Imports System.Web.Mvc
Imports System.Runtime.CompilerServices
Imports Model.Esperanto
Imports Business.Esperanto

Public Module HtmlExtensions

    Private Const HTML_BLANKSPACE As String = "&nbsp;"
    Private Const FORMAT_DATA As String = "dd/MM/yyyy"


    <Extension()>
    Public Function GetFormat_Date(ByRef dat As Nullable(Of DateTime)) As String

        Dim s As String = String.Empty

        If dat.HasValue AndAlso dat <> New Date Then
            s = dat.Value.ToString(FORMAT_DATA)
        End If

        Return s

    End Function

    ''' <summary>
    ''' Extensión del MVC.HtmlHelper que retorna la traducción de la etiqueta que llega por parámetro
    ''' </summary>
    ''' <param name="helper"></param>
    ''' <param name="etiqueta"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    <Extension()>
    Public Function Translation(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal etiqueta As String) As IHtmlString

        Dim IdIdioma As Integer = SessionHelper.IdIdioma
        Return helper.Raw(CacheHelper.Traduccio(IdIdioma, etiqueta))

    End Function

    <Extension()>
    Public Function EllipsisText(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal s As String, ByVal MaxLength As Integer) As String

        If s.Trim.Length <= MaxLength Then
            Return s
        End If
        Return s.Trim.Substring(0, MaxLength) & " .."

    End Function

#Region "dropdownlist"

    <Extension()>
    Public Function DropDownRol(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional ByVal ExcludeInvitado As Boolean = False, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim rol As New List(Of Rol)
        Dim SelecList As New List(Of SelectListItem)()

        rol = UsuariosManager.Instance.Get_Rol

        If rol IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In rol
                                 Select New SelectListItem() With {.Value = item.RolId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim).Trim(),
                                                                   .Selected = (item.RolId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownEstado(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim SelecList As New List(Of SelectListItem)()
        Dim estados As New List(Of Object)

        estados.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})
        estados.Add(New SelectListItem() With {.Value = EstadoUsuario.Activo, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "Activo")})
        estados.Add(New SelectListItem() With {.Value = EstadoUsuario.Inactivo, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "Inactivo")})


        SelecList.AddRange((From item In estados
                             Select New SelectListItem() With {.Value = item.Value,
                                                               .Text = item.Text,
                                                               .Selected = (.Value = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownIdioma(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim SelecList As New List(Of SelectListItem)()
        Dim idiomas As New List(Of Object)

        idiomas.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})
        idiomas.Add(New SelectListItem() With {.Value = 1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "Castellano")})
        idiomas.Add(New SelectListItem() With {.Value = 2, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "Catala")})

        SelecList.AddRange((From item In idiomas
                             Select New SelectListItem() With {.Value = item.Value,
                                                               .Text = item.Text,
                                                               .Selected = (.Value = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownPlazo(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim SelecList As New List(Of SelectListItem)()
        Dim plazos As New List(Of Object)

        plazos.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})
        plazos.Add(New SelectListItem() With {.Value = 1, .Text = "Si"})
        plazos.Add(New SelectListItem() With {.Value = 2, .Text = "No"})


        SelecList.AddRange((From item In plazos
                             Select New SelectListItem() With {.Value = item.Value,
                                                               .Text = item.Text,
                                                               .Selected = (.Value = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownAutor(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, ByVal SelectedId As Integer) As MvcHtmlString

        Dim autor As New List(Of Autor)
        Dim SelecList As New List(Of SelectListItem)()

        autor = LibrosManager.Instance.Get_Autor

        If autor IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In autor
                                 Select New SelectListItem() With {.Value = item.AutorId,
                                                                   .Text = item.Descripcion.Trim,
                                                                   .Selected = (item.AutorId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownIdiomaLibro(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, ByVal SelectedId As Integer) As MvcHtmlString

        Dim IdiomaLibro As New List(Of IdiomaLibro)
        Dim SelecList As New List(Of SelectListItem)()

        IdiomaLibro = LibrosManager.Instance.GetIdiomaLibro

        If IdiomaLibro IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In IdiomaLibro
                                 Select New SelectListItem() With {.Value = item.IdiomaId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim),
                                                                   .Selected = (item.IdiomaId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownTipoDocumento(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, ByVal SelectedId As Integer) As MvcHtmlString

        Dim TipoDocumento As New List(Of TipoDocumento)
        Dim SelecList As New List(Of SelectListItem)()

        TipoDocumento = LibrosManager.Instance.GetTipoLibro

        If TipoDocumento IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In TipoDocumento
                                 Select New SelectListItem() With {.Value = item.TipoId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim),
                                                                   .Selected = (item.TipoId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDowEditorial(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim editorial As New List(Of Editorial)
        Dim SelecList As New List(Of SelectListItem)()

        editorial = LibrosManager.Instance.Get_Editorial

        If editorial IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In editorial
                                 Select New SelectListItem() With {.Value = item.EditorialId,
                                                                   .Text = item.Descripcion.Trim,
                                                                   .Selected = (item.EditorialId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownGenero(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim genero As New List(Of Genero)
        Dim SelecList As New List(Of SelectListItem)()

        genero = LibrosManager.Instance.Get_Genero

        If genero IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In genero
                                 Select New SelectListItem() With {.Value = item.GeneroId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim).Trim(),
                                                                   .Selected = (item.GeneroId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function


    <Extension()>
    Public Function DropDownDisponibilidad(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, ByVal SelectedId As Integer) As MvcHtmlString

        Dim SelecList As New List(Of SelectListItem)()
        Dim disponibilidad As New List(Of Object)


        disponibilidad.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})
        disponibilidad.Add(New SelectListItem() With {.Value = 1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "Disponible")})
        disponibilidad.Add(New SelectListItem() With {.Value = 2, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "NoDisponible")})

        SelecList.AddRange((From item In disponibilidad
                             Select New SelectListItem() With {.Value = item.Value,
                                                               .Text = item.Text,
                                                               .Selected = (.Value = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

    <Extension()>
    Public Function DropDownPrestamo(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String) As MvcHtmlString

        Dim SelecList As New List(Of SelectListItem)()
        Dim disponibilidad As New List(Of Object)
        Dim SelectedId As Integer = -1


        disponibilidad.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})
        disponibilidad.Add(New SelectListItem() With {.Value = 1, .Text = "Si"})
        disponibilidad.Add(New SelectListItem() With {.Value = 2, .Text = "No"})

        SelecList.AddRange((From item In disponibilidad
                             Select New SelectListItem() With {.Value = item.Value,
                                                               .Text = item.Text,
                                                               .Selected = (.Value = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function



    <Extension()>
    Public Function DropDownEstadosPrestamos(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim EstadosPrestamos As New List(Of EstadoPrestamo)
        Dim SelecList As New List(Of SelectListItem)()

        EstadosPrestamos = PrestamosManager.Instance.GetEstadoPrestamo

        If EstadosPrestamos IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In EstadosPrestamos
                                 Select New SelectListItem() With {.Value = item.EstadoPrestamoId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim).Trim(),
                                                                   .Selected = (item.EstadoPrestamoId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function


    <Extension()>
    Public Function DropDownEstadosReserva(ByRef helper As System.Web.Mvc.HtmlHelper, ByVal Name As String, ByVal CssStyle As String, Optional SelectedId As Object = 0) As MvcHtmlString

        Dim EstadosReservas As New List(Of EstadoReserva)
        Dim SelecList As New List(Of SelectListItem)()

        EstadosReservas = ReservasManager.Instance.GetEstadosReserva

        If EstadosReservas IsNot Nothing Then

            SelecList.Add(New SelectListItem() With {.Value = -1, .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, "DefaultOption")})

            SelecList.AddRange((From item In EstadosReservas
                                 Select New SelectListItem() With {.Value = item.EstadoReservaId,
                                                                   .Text = CacheHelper.Traduccio(SessionHelper.IdIdioma, item.Descripcion.Trim).Trim(),
                                                                   .Selected = (item.EstadoReservaId = SelectedId)}).OrderBy(Function(s) IIf(s.Value = 0, "", s.Text)))
        End If

        Return helper.DropDownList(Name, SelecList, Nothing, New With {.class = CssStyle})

    End Function

#End Region

End Module
