﻿Option Explicit On
Option Strict On

#Region "Imports"

Imports System
Imports System.Web
Imports System.Configuration
Imports Model.Esperanto

#End Region

Public Class SessionHelper

    Private Const IdIdioma_Predeterminado As Integer = IdiomaEnum.Catala

    ''' <summary>
    ''' Contiene el código idioma del usuario ("es-ES", "en-CA"). 
    ''' </summary>
    ''' <value>Por defecto su valor es "es-Ca", es decir la aplicación estará en catalán</value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Shared Property IdIdioma() As Integer
        Get
            Dim obj As Object = HttpContext.Current.Session("IdIdioma")
            If obj Is Nothing Then
                Return IdIdioma_Predeterminado
            Else
                Return CInt(obj)
            End If

            Return CInt(HttpContext.Current.Session("IdIdioma"))
        End Get
        Set(ByVal value As Integer)
            HttpContext.Current.Session("IdIdioma") = value
        End Set
    End Property

    ''' <summary>
    ''' Almacena el usuario que se ha logeado
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Shared Property User() As Usuarios
        Get
            If HttpContext.Current.Session("User") Is Nothing Then
                Return New Usuarios With {.UserId = -1, .RolId = RolEnum.Invitado, .Nombre = String.Empty,
                                          .Apellido1 = String.Empty, .Apellido2 = String.Empty,
                                          .Email = String.Empty, .Direccion = String.Empty, .Estado = EstadoUsuario.Activo,
                                          .FechaAlta = Now, .Poblacion = String.Empty,
                                          .NIF = String.Empty, .Telf = String.Empty}
            Else
                Return CType(HttpContext.Current.Session("User"), Usuarios)
            End If
        End Get
        Set(ByVal value As Usuarios)
            HttpContext.Current.Session("User") = value
        End Set
    End Property

    ''' <summary>
    ''' Guarda los parámetros de busqueda del buscador de usuarios
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 27.04.2013</remarks>
    Public Shared Property BuscadorUsuarios() As Usuarios
        Get
            If HttpContext.Current.Session("BuscadorUsuarios") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("BuscadorUsuarios"), Usuarios)
            End If
        End Get
        Set(ByVal value As Usuarios)
            HttpContext.Current.Session("BuscadorUsuarios") = value
        End Set
    End Property

    ''' <summary>
    ''' Guarda los parámetros de busqueda del buscador de libros
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 07.05.2013</remarks>
    Public Shared Property BuscadorLibros() As Libros
        Get
            If HttpContext.Current.Session("BuscadorLibros") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("BuscadorLibros"), Libros)
            End If
        End Get
        Set(ByVal value As Libros)
            HttpContext.Current.Session("BuscadorLibros") = value
        End Set

    End Property

    ''' <summary>
    ''' Guarda los parámetros de busqueda del buscador de reservas
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 19.05.2013</remarks>
    Public Shared Property BuscadorReservas() As Reservas
        Get
            If HttpContext.Current.Session("BuscadorReservas") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("BuscadorReservas"), Reservas)
            End If
        End Get
        Set(ByVal value As Reservas)
            HttpContext.Current.Session("BuscadorReservas") = value
        End Set

    End Property

    ''' <summary>
    ''' Guarda los parámetros de busqueda del buscador de préstamos
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 24.05.2013</remarks>
    Public Shared Property BuscadorPrestamos() As Prestamos
        Get
            If HttpContext.Current.Session("BuscadorPrestamos") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("BuscadorPrestamos"), Prestamos)
            End If
        End Get
        Set(ByVal value As Prestamos)
            HttpContext.Current.Session("BuscadorPrestamos") = value
        End Set

    End Property

    ''' <summary>
    ''' Guarda las reservas que tiene un usuario
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Shared Property ReservasUser() As List(Of Reservas)
        Get
            If HttpContext.Current.Session("ReservasUser") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("ReservasUser"), List(Of Reservas))
            End If
        End Get
        Set(ByVal value As List(Of Reservas))
            HttpContext.Current.Session("ReservasUser") = value
        End Set

    End Property

    Public Shared Property PrestamosUser() As List(Of Prestamos)
        Get
            If HttpContext.Current.Session("PrestamosUser") Is Nothing Then
                Return Nothing
            Else
                Return CType(HttpContext.Current.Session("PrestamosUser"), List(Of Prestamos))
            End If
        End Get
        Set(ByVal value As List(Of Prestamos))
            HttpContext.Current.Session("PrestamosUser") = value
        End Set

    End Property

    ''' <summary>
    ''' Resetea todas las variables de session
    ''' </summary>
    ''' <remarks>JAC: 18.05.2013</remarks>
    Public Shared Sub Reset()

        IdIdioma = IdIdioma_Predeterminado

        User = New Usuarios With {.UserId = -1, .RolId = RolEnum.Invitado, .Nombre = String.Empty,
                                  .Apellido1 = String.Empty, .Apellido2 = String.Empty,
                                  .Email = String.Empty, .Direccion = String.Empty, .Estado = EstadoUsuario.Activo,
                                  .FechaAlta = Now, .Poblacion = String.Empty,
                                  .NIF = String.Empty, .Telf = String.Empty}

        BuscadorUsuarios = Nothing
        BuscadorLibros = Nothing
        ReservasUser = Nothing
        PrestamosUser = Nothing
        BuscadorReservas = Nothing
        BuscadorPrestamos = Nothing

    End Sub

End Class
