﻿Option Explicit On
Option Strict On

Imports Business.Esperanto
Imports Model.Esperanto

Namespace Esperanto

    Public Class LibrosController
        Inherits System.Web.Mvc.Controller

#Region "public"

        '
        ' GET: /Libros

        Function Buscador() As ActionResult

            Dim libros As Libros

            If SessionHelper.BuscadorLibros IsNot Nothing Then
                libros = SessionHelper.BuscadorLibros
            Else
                libros = (New Libros With {.AutorId = -1, .EditorialId = -1, .GeneroId = -1, .ISBN = String.Empty,
                                           .Titulo = String.Empty, .Disponible = -1, .IdiomaId = -1, .TipoId = -1})
            End If

            Return View(libros)

        End Function

        ''' <summary>
        ''' Retorna la vista Libro con los datos en blanco para introducir un nuevo libro
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 11.05.2013</remarks>
        Function Nuevo() As ActionResult

            Dim libro As New Libros

            libro.Autor = New Autor
            libro.Autor.Descripcion = String.Empty
            libro.AutorId = -1

            libro.Editorial = New Editorial
            libro.Editorial.Descripcion = String.Empty
            libro.EditorialId = -1

            libro.Genero = New Genero
            libro.Genero.Descripcion = String.Empty
            libro.GeneroId = -1

            libro.TipoDocumento = New TipoDocumento
            libro.TipoDocumento.Descripcion = String.Empty
            libro.TipoId = -1

            libro.IdiomaLibro = New IdiomaLibro
            libro.IdiomaLibro.Descripcion = String.Empty
            libro.IdiomaId = -1

            libro.ISBN = String.Empty
            libro.Titulo = String.Empty
            libro.Stock = 0

            Return View("Libro", libro)

        End Function

        ''' <summary>
        ''' Retorna la vista Libro con los datos de un libro
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 11.05.2013</remarks>
        Function Editar(ByVal LibroId As Integer) As ActionResult

            Dim libro As Libros

            Try
                libro = GetLibroBBDD(LibroId)
            Catch ex As Exception
                Return View("Error")
            End Try

            Return View("Libro", libro)

        End Function

        <ValidateInput(False)>
        Function NuevoLibro(ByVal KeysCollections As FormCollection) As ActionResult

            Dim libro As Libros
            Dim libroId As Integer


            libro = GetLibro(KeysCollections)

            Try

                libroId = LibrosManager.Instance.AddLibro(libro)

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return Content(libroId.ToString)

        End Function

        <ValidateInput(False)>
        Function EditarLibro(ByVal KeysCollections As FormCollection) As ActionResult

            Dim libro As Libros
            Dim libroId As Integer


            libro = GetLibro(KeysCollections)

            Try

                libroId = LibrosManager.Instance.EditLibro(libro)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return Content(libroId.ToString)

        End Function

        <HttpPost()>
        Function Buscar(ByVal Titulo As String, ByVal EditorialId As Integer, ByVal AutorId As Integer, ByVal GeneroId As Integer, ByVal Disponibilidad As Integer, ByVal ISBN As String, ByVal IdiomaId As Integer, ByVal TipoId As Integer, ByVal Prestado As Integer) As ActionResult

            Dim libros As List(Of Libros)

            Try

                ' Me guardo en la session los parámetros de búsqueda
                SessionHelper.BuscadorLibros = New Libros With {.Titulo = Titulo, .EditorialId = EditorialId, .AutorId = AutorId,
                                                                .GeneroId = GeneroId, .ISBN = ISBN, .Disponible = Disponibilidad,
                                                                .IdiomaId = IdiomaId, .TipoId = TipoId}

                libros = LibrosManager.Instance.Buscar(Titulo, EditorialId, AutorId, GeneroId, Disponibilidad, ISBN, IdiomaId, TipoId, Prestado)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return PartialView("_PartialResultadoLibros", libros)

        End Function

        ''' <summary>
        ''' Retorna un libro en base a su identificador
        ''' </summary>
        ''' <param name="LibroId"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 08.05.2013</remarks>
        <HttpGet()>
        <ValidateInput(False)>
        Function Detail(ByVal LibroId As Integer) As ActionResult

            Dim libro As Libros

            Try
                libro = GetLibroBBDD(LibroId)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return View("Libro", libro)

        End Function

#End Region

#Region "private"

        ''' <summary>
        ''' Consulta un libro en la bbdd con su identificador
        ''' </summary>
        ''' <param name="LibroId"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 12.05.2013</remarks>
        Private Function GetLibroBBDD(ByVal LibroId As Integer) As Libros

            Dim libro As Libros

            Try
                libro = LibrosManager.Instance.GetLibro(LibroId)
            Catch ex As Exception
                Throw ex
            End Try

            Return libro

        End Function

        ''' <summary>
        ''' Parsea a un objeto Libros los datos que hay en pantalla
        ''' </summary>
        ''' <param name="KeysCollections"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 11.05.2013</remarks>
        Private Function GetLibro(ByVal KeysCollections As FormCollection) As Libros

            Dim libro As New Libros

            If KeysCollections.Item("hdnLibroId") IsNot Nothing Then
                libro.LibroId = CInt(KeysCollections.Item("hdnLibroId"))
            End If

            libro.Titulo = KeysCollections.Item("txtTitulo")
            libro.EditorialId = CInt(KeysCollections.Item("ddlEditorial"))
            libro.AutorId = CInt(KeysCollections.Item("ddlAutor"))
            libro.GeneroId = CInt(KeysCollections.Item("ddlGenero"))
            libro.IdiomaId = CInt(KeysCollections.Item("ddlIdiomaLibro"))
            libro.TipoId = CInt(KeysCollections.Item("ddlTipoDocumento"))
            libro.ISBN = KeysCollections.Item("txtISBN")
            libro.Sinopsis = KeysCollections.Item("hdnSinopsis")
            libro.Stock = CInt(KeysCollections.Item("txtStock"))

            Return libro

        End Function

#End Region

    End Class

End Namespace