﻿Option Explicit On
Option Strict On

Imports Business.Esperanto
Imports Model.Esperanto

Namespace Esperanto
    Public Class PrestamosController
        Inherits System.Web.Mvc.Controller

        '
        ' GET: /PRestamos

        Function Index() As ActionResult

            Dim prestecs As New Prestamos

            If SessionHelper.BuscadorPrestamos IsNot Nothing Then
                prestecs = SessionHelper.BuscadorPrestamos
            Else
                prestecs.Libros = New Libros With {.Titulo = String.Empty, .AutorId = -1, .EditorialId = -1, .GeneroId = -1, .ISBN = String.Empty}
                prestecs.PrestamoId = -1
                prestecs.Usuarios = New Usuarios With {.NIF = String.Empty}
                prestecs.EstadoPrestamoId = -1
                prestecs.FechaPrestamoIni = Nothing
                prestecs.FechaPrestamoFin = Nothing
                prestecs.FechaRetornoIni = Nothing
                prestecs.FechaRetornoFin = Nothing
                prestecs.FueraPlazo = -1
            End If

            Return View(prestecs)

        End Function

        <HttpPost()>
        Function Prestar(ByVal ReservaId As Integer) As ActionResult

            Dim prestec As Prestamos

            Try

                prestec = PrestamosManager.Instance.AddPrestamo(ReservaId)

                ' Una vez realizada correctamente el préstamos (en caso de error se ejecutaria el Catch) 
                ' actualizo la session del usuario para agregarlo

                SessionHelper.PrestamosUser.Add(prestec)

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return Content(prestec.PrestamoId.ToString)

        End Function

        <HttpPost()>
        Function Retornar(ByVal PrestamoId As Integer) As ActionResult

            Dim prestec As Prestamos

            Try

                prestec = PrestamosManager.Instance.RetornarPrestamo(PrestamoId)

                ' Una vez realizada correctamente el préstamos (en caso de error se ejecutaria el Catch) 
                ' actualizo la session del usuario para eliminar este préstamo
                SessionHelper.PrestamosUser = (From a In SessionHelper.PrestamosUser Where a.PrestamoId <> prestec.PrestamoId Select a).ToList


            Catch ex As Exception
                Return Content("Error")
            End Try

            Return Content(prestec.PrestamoId.ToString)

        End Function

        ''' <summary>
        ''' Retorna préstamo en base a su identificador
        ''' </summary>
        ''' <param name="PrestamoId"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 25.05.2013</remarks>
        <HttpPost()>
        Function Detail(ByVal PrestamoId As Integer) As ActionResult

            Dim prestec As Prestamos

            Try

                prestec = PrestamosManager.Instance.GetPrestamo(PrestamoId)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return PartialView("_PartialPrestamo", prestec)

        End Function

        ''' <summary>
        ''' Realiza una búsqueda de los prestamos en función de los parámetros de entrada
        ''' </summary>
        ''' <param name="PrestamoId"></param>
        ''' <param name="NIF"></param>
        ''' <param name="Titulo"></param>
        ''' <param name="AutorId"></param>
        ''' <param name="ISBN"></param>
        ''' <param name="EstadoPrestamo"></param>
        ''' <param name="FechaPrestamoIni"></param>
        ''' <param name="FechaPrestamoFin"></param>
        ''' <param name="FechaRetornoIni"></param>
        ''' <param name="FechaRetornoFin"></param>
        ''' <param name="FueraPlazo"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 25.05.2013</remarks>
        <HttpPost()>
        Function Buscar(ByVal PrestamoId As String, ByVal NIF As String, ByVal Titulo As String,
                        ByVal AutorId As Integer, ByVal ISBN As String, ByVal EstadoPrestamo As EstadoPrestamoEnum,
                        ByVal FechaPrestamoIni As Nullable(Of Date), ByVal FechaPrestamoFin As Nullable(Of Date),
                        ByVal FechaRetornoIni As Nullable(Of Date), ByVal FechaRetornoFin As Nullable(Of Date), FueraPlazo As Integer) As ActionResult

            Dim Prestamos As List(Of Prestamos)
            Dim Prestamo As New Prestamos
            Dim UserId As Integer
            Dim FechaRetornaMax As Integer = CInt(ConfigurationManager.AppSettings("FechaRetornaMax"))

            If SessionHelper.User.RolId = RolEnum.Administrador Then
                ' Es un administrador, por tanto filtra no por el UserId
                UserId = -1
            ElseIf SessionHelper.User.RolId = RolEnum.Usuario Then
                ' Filtra por el usuario que está logueado y que guardo en la session
                UserId = SessionHelper.User.UserId
            End If

            Try

                Prestamo.Libros = New Libros With {.Titulo = Titulo, .AutorId = AutorId, .ISBN = ISBN}

                Prestamo.EstadoPrestamoId = EstadoPrestamo
                Prestamo.FechaPrestamoIni = If(FechaPrestamoIni.HasValue, FechaPrestamoIni.Value, Nothing)
                Prestamo.FechaPrestamoFin = If(FechaPrestamoFin.HasValue, FechaPrestamoFin.Value, Nothing)
                Prestamo.FechaRetornoIni = If(FechaRetornoIni.HasValue, FechaRetornoIni.Value, Nothing)
                Prestamo.FechaRetornoFin = If(FechaRetornoFin.HasValue, FechaRetornoFin.Value, Nothing)
                Prestamo.PrestamoId = If(PrestamoId = String.Empty, -1, CInt(PrestamoId))
                Prestamo.Usuarios = New Usuarios With {.NIF = NIF}

                ' Me guardo en la session los parámetros de búsqueda
                SessionHelper.BuscadorPrestamos = Prestamo

                Prestamos = PrestamosManager.Instance.Buscar(If(PrestamoId = String.Empty, -1, CInt(PrestamoId)), UserId, NIF, Titulo, AutorId, ISBN, EstadoPrestamo, FechaPrestamoIni, FechaPrestamoFin, FechaRetornoIni, FechaRetornoFin, FueraPlazo, FechaRetornaMax)

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return PartialView("_PartialResultadoPrestamos", Prestamos)

        End Function

    End Class

End Namespace