﻿Option Explicit On
Option Strict On

Imports Business.Esperanto
Imports Model.Esperanto

Namespace Esperanto
    Public Class ReservasController
        Inherits System.Web.Mvc.Controller

        '
        ' GET: /Reservas

        Function Index() As ActionResult

            Dim Reserva As New Reservas

            If SessionHelper.BuscadorReservas IsNot Nothing Then
                Reserva = SessionHelper.BuscadorReservas
            Else
                Reserva.Libros = New Libros With {.Titulo = String.Empty, .AutorId = -1, .EditorialId = -1, .GeneroId = -1, .ISBN = String.Empty}
                Reserva.ReservaId = -1
                Reserva.Usuarios = New Usuarios With {.NIF = String.Empty}
                Reserva.EstadoReservaId = -1
                Reserva.FechaReservaIni = Nothing
                Reserva.FechaReservaFin = Nothing
                Reserva.FechaCancelacionIni = Nothing
                Reserva.FechaCancelacionFin = Nothing
            End If

            Return View(Reserva)

        End Function

        <HttpPost()>
        Function Reservar(ByVal LibroId As Integer) As ActionResult

            Dim UserId = SessionHelper.User.UserId
            Dim Reserva As Reservas

            Try

                Reserva = ReservasManager.Instance.AddReserva(UserId, LibroId)

                ' Una vez realizada correctamente la reserva (en caso de error se ejecutaria el Catch) 
                ' actualizo la session del usuario para agregar la reserva

                SessionHelper.ReservasUser.Add(Reserva)

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return Content(Reserva.ReservaId.ToString)

        End Function

        ''' <summary>
        ''' Busca reservas con los parámetros de búsqueda indicados
        ''' </summary>
        ''' <param name="ReservaId"></param>
        ''' <param name="NIF"></param>
        ''' <param name="Titulo"></param>
        ''' <param name="AutorId"></param>
        ''' <param name="ISBN"></param>
        ''' <param name="EstadoReserva"></param>
        ''' <param name="FechaReservaIni"></param>
        ''' <param name="FechaReservaFin"></param>
        ''' <param name="FechaCancelacionIni"></param>
        ''' <param name="FechaCancelacionFin"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 19.05.2013</remarks>
        <HttpPost()>
        Function Buscar(ByVal ReservaId As String, ByVal NIF As String, ByVal Titulo As String,
                        AutorId As Integer, ByVal ISBN As String, ByVal EstadoReserva As EstadoReservaEnum,
                        ByVal FechaReservaIni As Nullable(Of Date), ByVal FechaReservaFin As Nullable(Of Date),
                        ByVal FechaCancelacionIni As Nullable(Of Date), ByVal FechaCancelacionFin As Nullable(Of Date)) As ActionResult

            Dim Reservas As List(Of Reservas)
            Dim Reserva As New Reservas
            Dim UserId As Integer


            If SessionHelper.User.RolId = RolEnum.Administrador Then
                ' Es un administrador, por tanto filtra no por el UserId
                UserId = -1
            ElseIf SessionHelper.User.RolId = RolEnum.Usuario Then
                ' Filtra por el usuario que está logueado y que guardo en la session
                UserId = SessionHelper.User.UserId
            End If

            Try

                Reserva.Libros = New Libros With {.Titulo = Titulo, .AutorId = AutorId, .ISBN = ISBN}

                Reserva.EstadoReservaId = EstadoReserva
                Reserva.FechaReservaIni = If(FechaReservaIni.HasValue, FechaReservaIni.Value, Nothing)
                Reserva.FechaReservaFin = If(FechaReservaFin.HasValue, FechaReservaFin.Value, Nothing)
                Reserva.FechaCancelacionIni = If(FechaCancelacionIni.HasValue, FechaCancelacionIni.Value, Nothing)
                Reserva.FechaCancelacionFin = If(FechaCancelacionFin.HasValue, FechaCancelacionFin.Value, Nothing)
                Reserva.ReservaId = If(ReservaId = String.Empty, -1, CInt(ReservaId))
                Reserva.Usuarios = New Usuarios With {.NIF = NIF}

                ' Me guardo en la session los parámetros de búsqueda
                SessionHelper.BuscadorReservas = Reserva

                Reservas = ReservasManager.Instance.Buscar(If(ReservaId = String.Empty, -1, CInt(ReservaId)), UserId, NIF, Titulo, AutorId, ISBN, EstadoReserva, FechaReservaIni, FechaReservaFin, FechaCancelacionIni, FechaCancelacionFin)

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return PartialView("_PartialResultadoReservas", Reservas)

        End Function

        ''' <summary>
        ''' Cancela la reserva de un usuario en base al identificador de la reserva
        ''' </summary>
        ''' <param name="ReservaId"></param>
        ''' <remarks>JAC: 19.05.2013</remarks>
        Function Cancelar(ByVal ReservaId As Integer) As ActionResult

            Try

                ReservasManager.Instance.Cancelar(ReservaId)

                ' Elimino la reserva que tengo en la session
                SessionHelper.ReservasUser = (From a In SessionHelper.ReservasUser Where a.ReservaId <> ReservaId Select a).ToList

            Catch ex As Exception
                Return Content("Error")
            End Try

            Return Content(ReservaId.ToString)

        End Function

        ''' <summary>
        ''' Retorna una reserva en base a su identificador
        ''' </summary>
        ''' <param name="ReservaId"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 21.05.2013</remarks>
        <HttpPost()>
        Function Detail(ByVal ReservaId As Integer) As ActionResult

            Dim Reserva As Reservas

            Try

                Reserva = ReservasManager.Instance.GetReserva(ReservaId)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return PartialView("_PartialReserva", Reserva)

        End Function

    End Class

End Namespace

