﻿Option Explicit On
Option Strict On

Imports Business.Esperanto
Imports Model.Esperanto

Namespace Esperanto

    Public Class UsuariosController
        Inherits System.Web.Mvc.Controller

        '
        ' GET: /Login

#Region "Public"

        ''' <summary>
        ''' Selecciona un usuario en función de su NIF y password
        ''' Si el usuario existe lo guarda en la session y retorna true
        ''' Si el usuario no existe retorna false
        ''' </summary>
        ''' <param name="NIF"></param>
        ''' <param name="Pass"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 14.04.2013</remarks>
        Function Login(ByVal NIF As String, ByVal Pass As String) As ActionResult

            Dim usuario As Usuarios

            Try

                usuario = UsuariosManager.Instance.Login(NIF, Pass)

                If usuario IsNot Nothing Then
                    ' Me guardo el usuario en la session
                    SessionHelper.User = usuario
                    SessionHelper.IdIdioma = usuario.IdIdioma

                    ' Cargo las reservas
                    SessionHelper.ReservasUser = ReservasManager.Instance.GetReservasByUserId(usuario.UserId)
                    ' Cargo los préstamos
                    SessionHelper.PrestamosUser = PrestamosManager.Instance.GetPrestamosByUserId(usuario.UserId)

                Else
                    Return Content("False")
                End If

            Catch ex As Exception
                Return Content("False")
            End Try

            Return Content("True")

        End Function

        ''' <summary>
        ''' Permite acceder a la aplicación a un usuario como invitado
        ''' Guarda en la session un usuario sin datos pero con el rol de invitado
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 14.04.2013</remarks>
        Function Invitado() As ActionResult

            SessionHelper.User = New Usuarios With {.UserId = -1, .RolId = RolEnum.Invitado, .Nombre = String.Empty,
                                                    .Apellido1 = String.Empty, .Apellido2 = String.Empty,
                                                    .Email = String.Empty, .Direccion = String.Empty, .Estado = EstadoUsuario.Activo,
                                                    .FechaAlta = Now, .Poblacion = String.Empty,
                                                    .NIF = String.Empty, .Telf = String.Empty}

            Return Content("True")

        End Function

        ''' <summary>
        ''' Retorna la partial de usuario para poder dar de alta un nuevo usuario
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 14.04.2013</remarks>
        Function Registro() As ActionResult

            Dim usuario As New Usuarios With {.UserId = -1, .RolId = -1, .Nombre = String.Empty,
                                              .Apellido1 = String.Empty, .Apellido2 = String.Empty,
                                              .Email = String.Empty, .Direccion = String.Empty, .Estado = EstadoUsuario.Activo,
                                              .FechaAlta = Now, .Poblacion = String.Empty,
                                              .NIF = String.Empty, .Telf = String.Empty}

            Return View("Usuario", usuario)

        End Function

        ''' <summary>
        ''' Retorna la partial de usuario para poder editar un usuario
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 14.04.2013</remarks>
        Function Perfil(ByVal Id As Nullable(Of Integer)) As ActionResult

            Dim usuario As New Usuarios

            If Id.HasValue = False Then Id = SessionHelper.User.UserId

            Try
                usuario = UsuariosManager.Instance.GetUser(Id.Value)
            Catch ex As Exception
                Return View("Error")
            End Try

            Return View("Usuario", usuario)

        End Function

        ''' <summary>
        ''' Da de alta un usuario en la aplicación, este es el registro de usuarios
        ''' </summary>
        ''' <param name="KeysCollections"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 15.04.2013</remarks>
        <HttpPost()>
        Function AddUser(ByVal KeysCollections As FormCollection) As ActionResult

            Dim UserId As Integer
            Dim user As New Usuarios


            user = GetUser(KeysCollections)
            user.Password = KeysCollections.Item("txtPassword")


            Try

                UserId = UsuariosManager.Instance.AddUser(user)

                If UserId > 0 Then
                    user.UserId = UserId
                    ' El usuario se ha agregado y automáticamente se informa la sessión
                    SessionHelper.User = user
                End If

            Catch ex As Exception
                Return View("Error")
            End Try

            Return Content(UserId.ToString)

        End Function

        ''' <summary>
        ''' Actualiza un usuario con los datos recogidos en la pantalla
        ''' </summary>
        ''' <param name="KeysCollections"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 21.04.2013</remarks>
        Function UpdateUser(ByVal KeysCollections As FormCollection) As ActionResult

            Dim user As New Usuarios
            Dim UserId As Integer


            user = GetUser(KeysCollections)

            Try

                UserId = UsuariosManager.Instance.UpdateUser(user)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return Content(UserId.ToString)

        End Function

        ''' <summary>
        ''' Retorna la partial de recuperar contraseña
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 24.04.2013</remarks>
        Function recover() As ActionResult
            Return View()
        End Function

        ''' <summary>
        ''' Comprueba si existe un usuario en la base de datos con estos parámetros
        ''' y si existe retorna un perfil de usuario para que pueda cambiar la contraseña
        ''' </summary>
        ''' <param name="NIF"></param>
        ''' <param name="Email"></param>
        ''' <param name="FechaNacimiento"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 25.04.2013</remarks>
        Function RecoverPass(ByVal NIF As String, ByVal Email As String, ByVal FechaNacimiento As Date) As ActionResult

            Dim usuario As Usuarios

            Try

                usuario = UsuariosManager.Instance.Recover(NIF, Email, FechaNacimiento)

                If usuario IsNot Nothing Then
                    ' Me guardo el usuario en la session
                    SessionHelper.User = usuario
                Else
                    Return Content("0")
                End If

            Catch ex As Exception
                Return View("Error")
            End Try

            Return Content(usuario.UserId.ToString)

        End Function

        ''' <summary>
        ''' Actualiza la contraseña
        ''' </summary>
        ''' <param name="UserId"></param>
        ''' <param name="Password"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 26.04.2013</remarks>
        <HttpPost()>
        Function UpdatePass(ByVal UserId As Integer, ByVal Password As String) As ActionResult

            Try

                UsuariosManager.Instance.UpdatePass(UserId, Password)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return Content("True")

        End Function

        ''' <summary>
        ''' Busca usuarios en función de los parámetros de búsqueda
        ''' </summary>
        ''' <param name="Nombre"></param>
        ''' <param name="Apellido1"></param>
        ''' <param name="Apellido2"></param>
        ''' <param name="Telefono"></param>
        ''' <param name="Rol"></param>
        ''' <param name="NIF"></param>
        ''' <param name="Poblacion"></param>
        ''' <param name="Estado"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 20.04.2013</remarks>
        <HttpPost()>
        Function Buscar(ByVal Nombre As String, ByVal Apellido1 As String, ByVal Apellido2 As String,
                        ByVal Telefono As String, ByVal NIF As String,
                        ByVal Poblacion As String, ByVal Rol As RolEnum, ByVal Estado As Integer, ByVal Prestado As Integer) As ActionResult

            Dim usuarios As List(Of Usuarios)

            Try

                If SessionHelper.User.RolId = RolEnum.Administrador Then
                    ' Me guardo en la session los parámetros de búsqueda
                    SessionHelper.BuscadorUsuarios = New Usuarios With {.Nombre = Nombre, .Apellido1 = Apellido1, .Apellido2 = Apellido2,
                                                                        .Telf = Telefono, .NIF = NIF, .Poblacion = Poblacion, .RolId = Rol,
                                                                        .Estado = Estado}
                End If

                usuarios = UsuariosManager.Instance.Buscar(Nombre, Apellido1, Apellido2, Telefono,
                                                           NIF, Poblacion, Rol, Estado, Prestado)

            Catch ex As Exception
                Return View("Error")
            End Try

            Return PartialView("_PartialResultadoUsuarios", usuarios)

        End Function

        ''' <summary>
        ''' Retorna la vista del buscador con los parámetros de búsqueda si están en la sesión
        ''' </summary>
        ''' <returns></returns>
        ''' <remarks>JAC: 26.04.2013</remarks>
        Function Buscador() As ActionResult

            Dim users As Usuarios

            If SessionHelper.BuscadorUsuarios IsNot Nothing Then
                users = SessionHelper.BuscadorUsuarios
            Else
                users = (New Usuarios With {.UserId = -1, .RolId = RolEnum.Buscador, .Nombre = String.Empty,
                                            .Apellido1 = String.Empty, .Apellido2 = String.Empty,
                                            .Email = String.Empty, .Direccion = String.Empty, .Estado = EstadoUsuario.Ninguno,
                                            .FechaAlta = Now, .Poblacion = String.Empty,
                                            .NIF = String.Empty, .Telf = String.Empty})
            End If

            Return View(users)

        End Function

#End Region

#Region "Private"

        ''' <summary>
        ''' Parsea a un objeto Usuarios los datos que hay en pantalla
        ''' </summary>
        ''' <param name="KeysCollections"></param>
        ''' <returns></returns>
        ''' <remarks>JAC: 22.04.2013</remarks>
        Private Function GetUser(ByVal KeysCollections As FormCollection) As Usuarios

            Dim user As New Usuarios

            user.UserId = CInt(KeysCollections.Item("hdnUserId"))
            user.Nombre = KeysCollections.Item("txtNombre")
            user.Apellido1 = KeysCollections.Item("txtApellido1")
            user.Apellido2 = KeysCollections.Item("txtApellido2")
            user.NIF = KeysCollections.Item("txtNIF")
            user.Email = KeysCollections.Item("txtEmail")
            user.FechaNacimiento = CDate(KeysCollections.Item("txtFechaNacimiento"))
            user.FechaAlta = CDate(KeysCollections.Item("hdnFechaAlta"))

            If Date.TryParse(KeysCollections.Item("hdnFechaBaja"), Nothing) Then user.FechaBaja = CDate(KeysCollections.Item("hdnFechaBaja"))

            user.Poblacion = KeysCollections.Item("txtPoblacion")
            user.IdIdioma = CInt(KeysCollections.Item("ddlIdioma"))
            user.FechaAlta = Now
            user.Direccion = KeysCollections.Item("txtDireccion")
            user.Telf = KeysCollections.Item("txtTelf")
            user.Estado = CInt(KeysCollections.Item("ddlEstado"))
            user.RolId = CInt(KeysCollections.Item("ddlRol"))

            ' Si el RolId = -1 se trata de ua alta de usuario y no de administrador, por tanto no tiene acceso al dropdown ddlRol y su rol es usuario
            If user.RolId = -1 Then
                user.RolId = RolEnum.Usuario
            End If

            Return user

        End Function

#End Region

    End Class

End Namespace
